@@ -2,7 +2,7 @@ import argparse, sys
 from pathlib import Path
 
 from xklb import consts, db, tube_backend, utils
-from xklb.consts import SC, DBType
+from xklb.consts import SC
 from xklb.utils import log
 
 
